==> 2.0.1.tar.gz: sakurairo/README.md <==
[![image](https://cdn.jsdelivr.net/gh/Fuukei/Public_Repository@latest/vision/readme/readme.png)](https://github.com/mirai-mamori/Sakurairo)

<h1 align="left">「iro」主题</h1>

> 一个多彩，轻松上手，体验完善，具有强大自定义功能的WordPress主题 [简体中文版](https://github.com/mirai-mamori/Sakurairo) [繁體中文版](https://github.com/Fuukei/Sakurairo-zh_tw)

[![GitHub release](https://img.shields.io/github/v/release/mirai-mamori/Sakurairo.svg?style=for-the-badge&logo=appveyor)](https://github.com/mirai-mamori/Sakurairo/releases/latest)[![GitHub Release Date](https://img.shields.io/github/release-date/mirai-mamori/Sakurairo?style=for-the-badge&logo=appveyor)](https://github.com/mirai-mamori/Sakurairo/releases)![GitHub code size in bytes](https://img.shields.io/github/languages/code-size/mirai-mamori/Sakurairo?style=for-the-badge&logo=appveyor)[![jsDelivr hits (GitHub)](https://img.shields.io/jsdelivr/gh/hm/Fuukei/Public_Repository?color=red&logo=jsdelivr&logoColor=red&style=for-the-badge)](https://www.jsdelivr.com/package/gh/mirai-mamori/sakurairo)


## 版本宣传：

### PV：

[![image](https://cdn.jsdelivr.net/gh/Fuukei/Public_Repository@latest/vision/readme/pv.png)](https://iro.tw/)

[![image](https://cdn.jsdelivr.net/gh/Fuukei/Public_Repository@latest/vision/readme/pvbilibili.png)](https://b23.tv/tTJun3)

[![image](https://cdn.jsdelivr.net/gh/Fuukei/Public_Repository@latest/vision/readme/pvyoutube.png)](https://www.youtube.com/watch?v=_rjlUY7MpqM)

### 图文：

[![image](https://cdn.jsdelivr.net/gh/Fuukei/Public_Repository@latest/vision/readme/ultramarine1.png)](https://iro.tw/)

[![image](https://cdn.jsdelivr.net/gh/Fuukei/Public_Repository@latest/vision/readme/ultramarine2.png)](https://iro.tw/)

[![image](https://cdn.jsdelivr.net/gh/Fuukei/Public_Repository@latest/vision/readme/ultramarine3.png)](https://iro.tw/)

[![image](https://cdn.jsdelivr.net/gh/Fuukei/Public_Repository@latest/vision/readme/ultramarine4.png)](https://iro.tw/)

## 使用相关：

[![image](https://cdn.jsdelivr.net/gh/Fuukei/Public_Repository@latest/vision/readme/irotw.png)](https://iro.tw/)

- 演示站点：https://demo.iro.tw/

- 主题交流群：[784229925](https://jq.qq.com/?_wv=1027&k=U5UJjRik)

- 如果在使用过程中遇到了任何问题，请**访问**本主题的 [官方站点](https://iro.tw/) 

- 在确认你遇到的现象确实是一个 Bug 后，请在 [Issues](https://github.com/mirai-mamori/Sakurairo/issues/new/choose) 提交问题，并为该问题尽可能的描述清楚，
按照提供的 issue 模板进行填写，谢谢配合。

## 主题下载：

[![image](https://cdn.jsdelivr.net/gh/Fuukei/Public_Repository@latest/vision/readme/dl.png)](https://iro.tw/)

[![image](https://cdn.jsdelivr.net/gh/Fuukei/Public_Repository@latest/vision/readme/dlgithub.png)](https://github.com/mirai-mamori/Sakurairo/releases/latest)

[![image](https://cdn.jsdelivr.net/gh/Fuukei/Public_Repository@latest/vision/readme/dlgitee.png)](https://gitee.com/mirai-mamori/Sakurairo)

## 支持我们：

[![image](https://cdn.jsdelivr.net/gh/Fuukei/Public_Repository@latest/vision/readme/starus.png)](https://github.com/mirai-mamori/Sakurairo)

[![image](https://cdn.jsdelivr.net/gh/Fuukei/Public_Repository@latest/vision/readme/sponsorme.png)](https://afdian.net/@mamori)

## 主题贡献：

### 主要贡献：

<a href="https://github.com/mirai-mamori"><img src="https://avatars3.githubusercontent.com/u/61381142?s=400" alt="mirai-mamori" width="100"></a>  <a href="https://github.com/Ukenn2112"><img src="https://avatars3.githubusercontent.com/u/60847880?s=400" alt="Ukenn" width="100"></a>  <a href="https://github.com/bymoye"><img src="https://avatars2.githubusercontent.com/u/27877470?s=400" alt="bymoye" width="100"></a>

### 特别贡献：

<a href="https://github.com/spirit1431007"><img src="https://avatars1.githubusercontent.com/u/29689177?s=400" alt="Spirit" width="100"></a>  <a href="https://jokerm.com/"><img src="https://cdn.jokerm.com/?/imgcdn/logo.png" alt="JokerM" width="100"></a>  <a href="https://github.com/FeiyuCode"><img src="https://avatars0.githubusercontent.com/u/46924793?s=400" alt="FeiyuCode" width="100"></a>  <a href="https://github.com/tumeneco"><img src="https://avatars0.githubusercontent.com/u/68286041?s=400" alt="Tumeneco" width="100"></a>  <a href="https://github.com/flurrychan "><img src="https://cdn.jsdelivr.net/gh/flurrychan/CDN/tx.jpg" alt="Flurrychan" width="100"></a>

### 参与贡献：

<a href="https://github.com/Sakurakouji-Runa"><img src="https://avatars2.githubusercontent.com/u/46081776?s=400" alt="Sakurakouji-Runa" width="100"></a>  <a href="https://github.com/givenhyh"><img src="https://avatars3.githubusercontent.com/u/37971883?s=400" alt="givenhyh" width="100"></a>  <a href="https://github.com/KotoriK"><img src="https://avatars.githubusercontent.com/u/52659125?s=400" alt="givenhyh" width="100"></a>

## 主题说明：

### 开源相关：

- 本主题**基于 [Sakura](https://github.com/mashirozx/Sakura) 主题进行开发**，使用 [GPL V2.0](https://github.com/mirai-mamori/Sakurairo/blob/master/LICENSE) 协议开源。

- 本主题使用了部分来自互联网的特效。由于版权及开源协议不明，无法具体说明相关信息。如果本主题使用到您制作的特效，烦请您通过邮件（me#okaeri.org）来取得联系。

### 引用相关：

- 本主题社交网络图标中，流畅设计图标引用于由Paradox设计的 [Fluent图标包](https://wwi.lanzous.com/ikyq5kgx0wb)

- 本主题社交网络图标中，沐氢图标引用于由缄默设计的 [沐氢图标包](https://www.coolapk.com/apk/com.muh2.icon)

- 本主题白猫样式Logo参考原主题作者白猫，由 [Hyacm](https://hyacm.com/acai/ui/143/sakura-logo/) 提供方案

- 本主题使用 Stevenjoezhang [Live2d-Widget](https://github.com/stevenjoezhang/live2d-widget) 作为默认看板娘

### 依赖相关：

- 本主题使用 Fuukei [Public Repository](https://github.com/Fuukei/Public_Repository) 作为默认静态资源库

- 本主题使用 Codestar [Codestar-Framework](https://github.com/Codestar/codestar-framework) 作为设置框架

- 本主题使用 YahnisElsts [Plugin-Update-Checker](https://github.com/YahnisElsts/plugin-update-checker) 以提供主题更新功能

## 希望你喜欢！

- Star 趋势  [![GitHub stars](https://img.shields.io/github/stars/mirai-mamori/Sakurairo?logo=github&style=social)](https://github.com/mirai-mamori/Sakurairo/stargazers)

[![Stargazers over time](https://starchart.cc/mirai-mamori/Sakurairo.svg)](https://github.com/mirai-mamori/Sakurairo/stargazers)

==> 2.0.1.1.tar.gz: sakurairo/README.md <==
[![image](https://cdn.jsdelivr.net/gh/Fuukei/Public_Repository@latest/vision/readme/readme.png)](https://github.com/mirai-mamori/Sakurairo)

<h1 align="left">「iro」主题</h1>

> 一个多彩，轻松上手，体验完善，具有强大自定义功能的WordPress主题 [简体中文版](https://github.com/mirai-mamori/Sakurairo) [繁體中文版](https://github.com/Fuukei/Sakurairo-zh_tw)

[![GitHub release](https://img.shields.io/github/v/release/mirai-mamori/Sakurairo.svg?style=for-the-badge&logo=appveyor)](https://github.com/mirai-mamori/Sakurairo/releases/latest)[![GitHub Release Date](https://img.shields.io/github/release-date/mirai-mamori/Sakurairo?style=for-the-badge&logo=appveyor)](https://github.com/mirai-mamori/Sakurairo/releases)![GitHub code size in bytes](https://img.shields.io/github/languages/code-size/mirai-mamori/Sakurairo?style=for-the-badge&logo=appveyor)[![jsDelivr hits (GitHub)](https://img.shields.io/jsdelivr/gh/hm/Fuukei/Public_Repository?color=red&logo=jsdelivr&logoColor=red&style=for-the-badge)](https://www.jsdelivr.com/package/gh/mirai-mamori/sakurairo)


## 版本宣传：

### PV：

[![image](https://cdn.jsdelivr.net/gh/Fuukei/Public_Repository@latest/vision/readme/pv.png)](https://iro.tw/)

[![image](https://cdn.jsdelivr.net/gh/Fuukei/Public_Repository@latest/vision/readme/pvbilibili.png)](https://b23.tv/tTJun3)

[![image](https://cdn.jsdelivr.net/gh/Fuukei/Public_Repository@latest/vision/readme/pvyoutube.png)](https://www.youtube.com/watch?v=_rjlUY7MpqM)

### 图文：

[![image](https://cdn.jsdelivr.net/gh/Fuukei/Public_Repository@latest/vision/readme/ultramarine1.png)](https://iro.tw/)

[![image](https://cdn.jsdelivr.net/gh/Fuukei/Public_Repository@latest/vision/readme/ultramarine2.png)](https://iro.tw/)

[![image](https://cdn.jsdelivr.net/gh/Fuukei/Public_Repository@latest/vision/readme/ultramarine3.png)](https://iro.tw/)

[![image](https://cdn.jsdelivr.net/gh/Fuukei/Public_Repository@latest/vision/readme/ultramarine4.png)](https://iro.tw/)

## 使用相关：

[![image](https://cdn.jsdelivr.net/gh/Fuukei/Public_Repository@latest/vision/readme/irotw.png)](https://iro.tw/)

- 演示站点：https://demo.iro.tw/

- 主题交流群：[784229925](https://jq.qq.com/?_wv=1027&k=U5UJjRik)

- 如果在使用过程中遇到了任何问题，请**访问**本主题的 [官方站点](https://iro.tw/) 

- 在确认你遇到的现象确实是一个 Bug 后，请在 [Issues](https://github.com/mirai-mamori/Sakurairo/issues/new/choose) 提交问题，并为该问题尽可能的描述清楚，
按照提供的 issue 模板进行填写，谢谢配合。

## 主题下载：

[![image](https://cdn.jsdelivr.net/gh/Fuukei/Public_Repository@latest/vision/readme/dl.png)](https://iro.tw/)

[![image](https://cdn.jsdelivr.net/gh/Fuukei/Public_Repository@latest/vision/readme/dlgithub.png)](https://github.com/mirai-mamori/Sakurairo/releases/latest)

[![image](https://cdn.jsdelivr.net/gh/Fuukei/Public_Repository@latest/vision/readme/dlgitee.png)](https://gitee.com/mirai-mamori/Sakurairo)

## 支持我们：

[![image](https://cdn.jsdelivr.net/gh/Fuukei/Public_Repository@latest/vision/readme/starus.png)](https://github.com/mirai-mamori/Sakurairo)

[![image](https://cdn.jsdelivr.net/gh/Fuukei/Public_Repository@latest/vision/readme/sponsorme.png)](https://afdian.net/@mamori)

## 主题贡献：

### 主要贡献：

<a href="https://github.com/mirai-mamori"><img src="https://avatars3.githubusercontent.com/u/61381142?s=400" alt="mirai-mamori" width="100"></a>  <a href="https://github.com/Ukenn2112"><img src="https://avatars3.githubusercontent.com/u/60847880?s=400" alt="Ukenn" width="100"></a>  <a href="https://github.com/bymoye"><img src="https://avatars2.githubusercontent.com/u/27877470?s=400" alt="bymoye" width="100"></a>

### 特别贡献：

<a href="https://github.com/spirit1431007"><img src="https://avatars1.githubusercontent.com/u/29689177?s=400" alt="Spirit" width="100"></a>  <a href="https://jokerm.com/"><img src="https://cdn.jokerm.com/?/imgcdn/logo.png" alt="JokerM" width="100"></a>  <a href="https://github.com/FeiyuCode"><img src="https://avatars0.githubusercontent.com/u/46924793?s=400" alt="FeiyuCode" width="100"></a>  <a href="https://github.com/tumeneco"><img src="https://avatars0.githubusercontent.com/u/68286041?s=400" alt="Tumeneco" width="100"></a>  <a href="https://github.com/flurrychan "><img src="https://cdn.jsdelivr.net/gh/flurrychan/CDN/tx.jpg" alt="Flurrychan" width="100"></a>

### 参与贡献：

<a href="https://github.com/Sakurakouji-Runa"><img src="https://avatars2.githubusercontent.com/u/46081776?s=400" alt="Sakurakouji-Runa" width="100"></a>  <a href="https://github.com/givenhyh"><img src="https://avatars3.githubusercontent.com/u/37971883?s=400" alt="givenhyh" width="100"></a>  <a href="https://github.com/KotoriK"><img src="https://avatars.githubusercontent.com/u/52659125?s=400" alt="KotoriK" width="100"></a>

## 主题说明：

### 开源相关：

- 本主题**基于 [Sakura](https://github.com/mashirozx/Sakura) 主题进行开发**，使用 [GPL V2.0](https://github.com/mirai-mamori/Sakurairo/blob/master/LICENSE) 协议开源。

- 本主题使用了部分来自互联网的特效。由于版权及开源协议不明，无法具体说明相关信息。如果本主题使用到您制作的特效，烦请您通过邮件（me#okaeri.org）来取得联系。

### 引用相关：

- 本主题社交网络图标中，流畅设计图标引用于由Paradox设计的 [Fluent图标包](https://wwi.lanzous.com/ikyq5kgx0wb)

- 本主题社交网络图标中，沐氢图标引用于由缄默设计的 [沐氢图标包](https://www.coolapk.com/apk/com.muh2.icon)

- 本主题白猫样式Logo参考原主题作者白猫，由 [Hyacm](https://hyacm.com/acai/ui/143/sakura-logo/) 提供方案

- 本主题使用 Stevenjoezhang [Live2d-Widget](https://github.com/stevenjoezhang/live2d-widget) 作为默认看板娘

### 依赖相关：

- 本主题使用 Fuukei [Public Repository](https://github.com/Fuukei/Public_Repository) 作为默认静态资源库

- 本主题使用 Codestar [Codestar-Framework](https://github.com/Codestar/codestar-framework) 作为设置框架

- 本主题使用 YahnisElsts [Plugin-Update-Checker](https://github.com/YahnisElsts/plugin-update-checker) 以提供主题更新功能

## 希望你喜欢！

- Star 趋势  [![GitHub stars](https://img.shields.io/github/stars/mirai-mamori/Sakurairo?logo=github&style=social)](https://github.com/mirai-mamori/Sakurairo/stargazers)

[![Stargazers over time](https://starchart.cc/mirai-mamori/Sakurairo.svg)](https://github.com/mirai-mamori/Sakurairo/stargazers)
